<?php
function ibiz_get_color_scheme() {
	$ibiz_color = get_theme_mod('color_scheme_ibiz', 'orange.css');
	if ( $ibiz_color == 'default.css' ) {
		$color = '#31a3dd';
	} else if ( $ibiz_color == 'orange.css' ) { 
		$color = '#f8504b';
	} else if ( $ibiz_color == 'green.css' ) {
		$color = '#33a568';
	} else if ( $ibiz_color == 'DonJuan.css' ) {
		$color = '#5C4B51';
	}
	return $color;
}
add_action( 'wp_enqueue_scripts', 'iBiz_theme_setup_enqueue_styles' );
function iBiz_theme_setup_enqueue_styles() {
	$parent_style = 'awada'; // This is 'awada' for the Awada theme.
    wp_enqueue_style( $parent_style, get_template_directory_uri() . '/style.css', array( 'bootstrap','owl-theme-default' ) );
    wp_enqueue_style( 'ibiz',
        get_stylesheet_directory_uri() . '/style.css',
        array( $parent_style ),
        wp_get_theme()->get('Version')
    );
	$color_scheme_ibiz = get_theme_mod('color_scheme_ibiz', 'orange.css');
	wp_enqueue_style( 'color-scheme', get_stylesheet_directory_uri(). '/css/skins/' . esc_attr($color_scheme_ibiz) );
	
	$ibiz_color = ibiz_get_color_scheme();
	$ibiz_css = '
		#sitetopbar {
			background: '.$ibiz_color.';
		}
		#awada_footer_area li a, #awada_footer_area a {
			color: '.$ibiz_color.';
		}
		#copyrights {
			background: '.$ibiz_color.';
		}';
	wp_add_inline_style( 'color-scheme', $ibiz_css, 99 );
}

function ibiz_theme_setup()
{
	$ibiz_color = ibiz_get_color_scheme();;
	/* Child Text Domain */
	load_child_theme_textdomain('ibiz', get_stylesheet_directory_uri() . '/lang');
	Kirki::add_config( 'ibiz_theme', array(
		'capability'    => 'edit_theme_options',
		'option_type'   => 'theme_mod',
	) );
	
	Kirki::add_field('ibiz_theme', array(
		'settings'          => 'color_scheme_ibiz',
		'label'             => esc_html__('Color scheme', 'ibiz'),
		'description'       => esc_html__('Select a color scheme', 'ibiz'),
		'section'           => 'general_sec',
		'type'              => 'preset',
		'priority'          => 9,
		'default'           => 'orange.css',
		'transport'         =>'auto',
		'sanitize_callback' => 'esc_attr',
		'choices'    =>array(
			'default.css'=>array(
				'label' => esc_html__('Default','ibiz'),
			),
			'DonJuan.css'=>array(
				'label' => esc_html__('Coffee','ibiz'),
			),
			'green.css'=>array(
				'label' => esc_html__('Green','ibiz'),
			),
			'orange.css'=>array(
				'label' => esc_html__('Orange','ibiz'),
			),
		)
	));
	Kirki::add_field('ibiz_theme', array(
		'settings'          => 'header_topbar_bg_color_ibiz',
		'label'             => esc_html__('Header Top Bar Background Color', 'ibiz'),
		'description'       => esc_html__('Change Top bar Background Color', 'ibiz'),
		'section'           => 'colors',
		'type'              => 'color',
		'priority'          => 9,
		'default'           => $ibiz_color,
		'transport'         =>'auto',
		'output'            => array(
			array(
				'element'  => '#sitetopbar',
				'property' => 'background',
			),
			array(
				'element'  => '#sitetopbar',
				'property' => 'border-bottom',
			),
		),
	));
	Kirki::add_field('ibiz_theme', array(
		'settings'          => 'footer_link_text_color_ibiz',
		'label'             => esc_html__('Footer Link Text Color', 'ibiz'),
		'description'       => esc_html__('Change Footer Link Text Color', 'ibiz'),
		'section'           => 'footer_sec',
		'type'              => 'color',
		'priority'          => 9,
		'default'			=> $ibiz_color,
		'output'            => array(
			array(
				'element'  => '#awada_footer_area li a, #awada_footer_area a',
				'property' => 'color',
			),
		),
		'transport'         => 'auto',
	));
	Kirki::add_field('ibiz_theme', array(
		'settings'          => 'copyright_section_bg_color_ibiz',
		'label'             => esc_html__('Copyright Section Background Color', 'ibiz'),
		'description'       => esc_html__('Change Copyright Section Background Color', 'ibiz'),
		'section'           => 'footer_sec',
		'type'              => 'color',
		'priority'          => 9,
		'default'           => $ibiz_color,
		'output'            => array(
			array(
				'element'  => '#copyrights',
				'property' => 'background',
			),
		),
		'transport'         => 'auto',
		'choices'     => array(
			'alpha' => true,
		),
	));
	/* $a = get_option('awada_theme_options');
	$a['color_scheme'] = 'default.css';
	$a['header_topbar_bg_color'] = '#31a3dd';
	//$a['footer_text_color'] = '#31a3dd';
	update_option("awada_theme_options",$a); */
}
add_action( 'after_setup_theme', 'ibiz_theme_setup' );

function ibiz_customize_register( $wp_customize ) {
	$wp_customize->remove_control( 'awada_theme_options[color_scheme]' );
	$wp_customize->remove_control( 'awada_theme_options[header_topbar_bg_color]' );
	$wp_customize->remove_control( 'awada_theme_options[copyright_section_bg_color]' );
	$wp_customize->remove_control( 'awada_theme_options[footer_link_text_color]' );
}
add_action('customize_register', 'ibiz_customize_register', 100 );